/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.manager.web.controller.openapi;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.inlong.common.pojo.agent.TaskRequest;
import org.apache.inlong.common.pojo.agent.TaskResult;
import org.apache.inlong.common.pojo.agent.TaskSnapshotRequest;
import org.apache.inlong.manager.common.beans.Response;
import org.apache.inlong.manager.service.core.AgentService;
import org.apache.inlong.manager.service.core.ThirdPartyClusterService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
@RequestMapping("/openapi/agent")
@Api(tags = "Agent Config")
public class AgentController {

    @Autowired
    private AgentService agentService;
    @Autowired
    private ThirdPartyClusterService thirdPartyClusterService;

    @PostMapping("/getManagerIpList")
    @ApiOperation(value = "Get inlong manager ip list")
    public Response<List<String>> getInLongManagerIp() {
        return Response.success(thirdPartyClusterService.listClusterIpByType("inlong-openapi"));
    }

    @PostMapping("/reportSnapshot")
    @ApiOperation(value = "Report source task snapshot")
    public Response<Boolean> reportSnapshot(@RequestBody TaskSnapshotRequest request) {
        return Response.success(agentService.reportSnapshot(request));
    }

    @PostMapping("/reportAndGetTask")
    @ApiOperation(value = "Report task result and get next tasks")
    public Response<TaskResult> reportAndGetTask(@RequestBody TaskRequest request) {
        agentService.report(request);
        return Response.success(agentService.getTaskResult(request));
    }

}
